==> polaris-ui-foundation-1.1.4.tgz: package/src/components/datebox/DateBox.tsx <==
import React, { useCallback, useEffect, useState } from "react";
import DateRangeBox from "devextreme-react/date-range-box";
import DropDownButton from "devextreme-react/drop-down-button";
import { DateboxProps } from "./types";

const DateDropDown = (props: DateboxProps) => {
  const { onDateChange, data } = props;
  const [selectedOption, setSelectedOption] = useState<string | null>("");
  const [dateboxData, setDateboxData] = useState<null | any>(null);

  useEffect(() => {
    if (data) {
      setDateboxData(data);
    }
  }, [data]);

  const handleOptionSelect = useCallback(
    (option: string) => {
      setSelectedOption(option);
      const endTime = new Date();
      switch (option) {
        case dateboxData?.dateRange[0].datepick:
          const startOfWeek = new Date(
            endTime.getFullYear(),
            endTime.getMonth(),
            endTime.getDate() - endTime.getDay()
          );
          let thisWeek = { value: [startOfWeek, endTime] };
          onDateChange(thisWeek);
          break;
        case dateboxData?.dateRange[1].datepick:
          const startOfMonth = new Date(
            endTime.getFullYear(),
            endTime.getMonth(),
            1
          );
          let thisMonth = { value: [startOfMonth, endTime] };
          onDateChange(thisMonth);
          break;
        case dateboxData?.dateRange[2].datepick:
          break;
        case dateboxData?.dateRange[3].datepick:
          const last7DaysStartDate = new Date();
          last7DaysStartDate.setDate(last7DaysStartDate.getDate() - 6);
          let lastSevenDays = { value: [last7DaysStartDate, endTime] };
          onDateChange(lastSevenDays);
          break;
        case dateboxData?.dateRange[4].datepick:
          const last30DaysStartDate = new Date();
          last30DaysStartDate.setDate(last30DaysStartDate.getDate() - 29);
          let lastThirtyDays = { value: [last30DaysStartDate, endTime] };
          onDateChange(lastThirtyDays);
          break;
        default:
          break;
      }
    },
    [onDateChange, dateboxData?.dateRange]
  );

  useEffect(() => {
    if (dateboxData) {
      handleOptionSelect(dateboxData?.dateRange[1].datepick ?? "");
    }
  }, [handleOptionSelect, dateboxData]);

  return (
    <div>
      <div
        style={{
          display: "flex",
          width: "400px",
          justifyContent: "space-between",
        }}
      >
        <div
          style={{
            display: "flex",
            width: "400px",
            justifyContent: "space-between",
          }}
        >
          <DropDownButton
            dropDownOptions={{ width: "auto" }}
            splitButton={false}
            text={selectedOption || ""}
            displayExpr="datepick"
            items={dateboxData?.dateRange}
            onItemClick={(e) => handleOptionSelect(e.itemData.datepick)}
          />
        </div>
        {selectedOption === dateboxData?.dateRange[2].datepick && (
          <DateRangeBox multiView={false} onValueChanged={onDateChange} />
        )}
      </div>
    </div>
  );
};

export default DateDropDown;

==> polaris-ui-foundation-1.2.9.tgz: package/src/components/datebox/DateBox.tsx <==
import React, { useCallback, useEffect, useState } from "react";
import DateRangeBox from "devextreme-react/date-range-box";
import DropDownButton from "devextreme-react/drop-down-button";
import { DateboxProps } from "./types";

const DateDropDown = (props: DateboxProps) => {
  const { onDateChange, data } = props;
  const [selectedOption, setSelectedOption] = useState<string | null>("");
  const [dateboxData, setDateboxData] = useState<null | any>(null);

  useEffect(() => {
    if (data) {
      setDateboxData(data);
    }
  }, [data]);

  const handleOptionSelect = useCallback(
    (option: string) => {
      setSelectedOption(option);
      const endTime = new Date();
      switch (option) {
        case dateboxData?.dateRange[0].datepick:
          const startOfWeek = new Date(
            endTime.getFullYear(),
            endTime.getMonth(),
            endTime.getDate() - endTime.getDay()
          );
          const frequencyWeek = "thisWeek";
          let thisWeek = { value: [startOfWeek, endTime, frequencyWeek] };
          onDateChange(thisWeek);
          break;
        case dateboxData?.dateRange[1].datepick:
          const startOfMonth = new Date(
            endTime.getFullYear(),
            endTime.getMonth(),
            1
          );
          const frequencyMonth = "thisMonth";
          let thisMonth = { value: [startOfMonth, endTime, frequencyMonth] };
          onDateChange(thisMonth);
          break;
        case dateboxData?.dateRange[2].datepick:
          break;
        case dateboxData?.dateRange[3].datepick:
          const last7DaysStartDate = new Date();
          last7DaysStartDate.setDate(last7DaysStartDate.getDate() - 6);
          const frequency7days = "last7Days";
          let lastSevenDays = {
            value: [last7DaysStartDate, endTime, frequency7days],
          };
          onDateChange(lastSevenDays);
          break;
        case dateboxData?.dateRange[4].datepick:
          const last30DaysStartDate = new Date();
          last30DaysStartDate.setDate(last30DaysStartDate.getDate() - 29);
          const frequency30days = "last30Days";
          let lastThirtyDays = {
            value: [last30DaysStartDate, endTime, frequency30days],
          };
          onDateChange(lastThirtyDays);
          break;
        default:
          break;
      }
    },
    [onDateChange, dateboxData?.dateRange]
  );

  useEffect(() => {
    if (dateboxData) {
      handleOptionSelect(dateboxData?.dateRange[1].datepick ?? "");
    }
  }, [handleOptionSelect, dateboxData]);

  return (
    <div>
      <div
        style={{
          display: "flex",
          width: "400px",
          justifyContent: "space-between",
        }}
      >
        <div
          style={{
            display: "flex",
            width: "400px",
            justifyContent: "space-between",
          }}
        >
          <DropDownButton
            dropDownOptions={{ width: "auto" }}
            splitButton={false}
            text={selectedOption || ""}
            displayExpr="datepick"
            items={dateboxData?.dateRange}
            onItemClick={(e) => handleOptionSelect(e.itemData.datepick)}
          />
        </div>
        {selectedOption === dateboxData?.dateRange[2].datepick && (
          <DateRangeBox multiView={false} onValueChanged={onDateChange} />
        )}
      </div>
    </div>
  );
};

export default DateDropDown;
